@@ -1,18 +1,18 @@
-#<<<
-use strict; use warnings;
-#>>>
+use strict;
+use warnings;
 
 package Time::Out;
 
-our $VERSION = '0.23';
+# keeping the following $VERSION declaration on a single line is important
+#<<<
+use version 0.9915; our $VERSION = version->declare( '1.0.0' );
+#>>>
 
 use Exporter                    qw( import );
 use Scalar::Util                qw( blessed reftype );
 use Time::Out::Exception        qw();
-use Time::Out::ParamConstraints qw( assert_non_negative_number assert_plain_coderef is_plain_coderef );
-use Try::Tiny                   qw( catch finally try );
-
-sub _timeout( $$@ );
+use Time::Out::ParamConstraints qw( assert_NonNegativeNumber assert_CodeRef );
+use Try::Tiny                   qw( finally try );
 
 BEGIN {
   # if possible use Time::HiRes drop-in replacements
@@ -26,8 +26,8 @@ our @EXPORT_OK = qw( timeout );
 sub timeout( $@ ) {
   my $context = wantarray;
   # wallclock seconds
-  my $timeout   = assert_non_negative_number shift;
-  my $code      = assert_plain_coderef pop;
+  my $timeout   = assert_NonNegativeNumber shift;
+  my $code      = assert_CodeRef pop;
   my @code_args = @_;
 
   my $exception;
@@ -40,11 +40,11 @@ sub timeout( $@ ) {
 
   {
 # https://stackoverflow.com/questions/1194113/whats-the-difference-between-ignoring-a-signal-and-telling-it-to-do-nothing-in
-# disable ALRM handling to prevent possible race condition between end of
-# eval and execution of alarm(0) after eval
+# disable ALRM handling to prevent possible race condition between the end of the
+# try block and the execution of alarm(0) in the finally block
     local $SIG{ ALRM } = 'IGNORE';
     try {
-      local $SIG{ ALRM } = sub { die $code }; ## no critic (RequireCarping)
+      local $SIG{ ALRM } = sub { die Time::Out::Exception->new( previous_exception => $@, timeout => $timeout ) }; ## no critic (RequireCarping)
       if ( $remaining_time_on_previous_timer and $remaining_time_on_previous_timer < $timeout ) {
         # a shorter timer was pending, let's use it instead
         alarm $remaining_time_on_previous_timer;
@@ -57,14 +57,13 @@ sub timeout( $@ ) {
           : $result[ 0 ] = $code->( @code_args )    # scalar context
         : $code->( @code_args );                    # void context
       alarm 0;
-    } catch {
-      $exception = ( is_plain_coderef $_ and $_ eq $code ) ? Time::Out::Exception->new( previous_exception => $@ ) : $_;
     } finally {
       alarm 0;
+      $exception = $_[ 0 ] if @_;
     }
   }
 
-  my $elapsed_time = time() - $start_time;
+  my $elapsed_time = time - $start_time;
   my $new_timeout  = $remaining_time_on_previous_timer - $elapsed_time;
 
   if ( $new_timeout > 0 ) {
