@@ -1,6 +1,5 @@
-#<<<
-use strict; use warnings;
-#>>>
+use strict;
+use warnings;
 
 use subs qw ( _which );
 
@@ -8,10 +7,9 @@ use Config         qw( %Config );
 use File::Basename qw( basename );
 use File::Spec     qw();
 
-my ( $blib_lib, $local_lib_root, $local_bin, $local_lib, $prove_rc_file, $t_lib );
+my ( $local_lib_root, $local_bin, $local_lib, $prove_rc_file, $t_lib );
 
 BEGIN {
-  $blib_lib       = File::Spec->catfile( $ENV{ PWD },     qw( blib lib ) );
   $local_lib_root = File::Spec->catfile( $ENV{ PWD },     'local' );
   $local_bin      = File::Spec->catfile( $local_lib_root, qw( bin ) );
   $local_lib      = File::Spec->catfile( $local_lib_root, qw( lib perl5 ) );
@@ -22,36 +20,29 @@ use lib $local_lib;
 
 # do not use "local" in the following line because then _which() will no see
 # the modified PATH
-$ENV{ PATH } = exists $ENV{ PATH } ? "$local_bin$Config{ path_sep }$ENV{ PATH }" : $local_bin; ## no critic (RequireLocalizedPunctuationVars)
+$ENV{ PATH } = ## no critic (RequireLocalizedPunctuationVars)
+  exists $ENV{ PATH }
+  ? "$local_bin$Config{ path_sep }$ENV{ PATH }"
+  : $local_bin; ## no critic (RequireLocalizedPunctuationVars)
 
 {
   no warnings 'once'; ## no critic (ProhibitNoWarnings)
   *MY::postamble = sub {
     my $make_fragment = '';
 
-    $make_fragment .= <<"MAKE_FRAGMENT" if _which 'cpanm';
+    $make_fragment .= <<"MAKE_FRAGMENT";
 export PATH := $ENV{ PATH }
 
 ifdef PERL5LIB
-  PERL5LIB := @{ [ -d $t_lib ? "$t_lib:" : () ] }$blib_lib:$local_lib:\$(PERL5LIB)
+  PERL5LIB := ${ \( -d $t_lib ? "$t_lib:" : '' ) }$local_lib:\$(PERL5LIB)
 else
-  export PERL5LIB := @{ [ -d $t_lib ? "$t_lib:" : () ] }$blib_lib:$local_lib
+  export PERL5LIB := ${ \( -d $t_lib ? "$t_lib:" : '' ) }$local_lib
 endif
 
-$local_lib_root: cpanfile
-	\$(NOECHO) rm -fr \$@
-	\$(NOECHO) cpanm --no-man-pages --local-lib-contained \$@ --installdeps .
-
-.PHONY: installdeps
-installdeps: $local_lib_root
-MAKE_FRAGMENT
-
-    $make_fragment .= <<"MAKE_FRAGMENT";
-
 # runs the last modified test script
 .PHONY: testlm
 testlm:
-	\$(NOECHO) \$(MAKE) TEST_FILES=\$\$(find t -name '*.t' -printf '%T@ %p\\n' | sort -nr | head -1 | cut -d' ' -f2) test
+	\$(NOECHO) \$(MAKE) TEST_FILES=\$\$(perl -e 'print STDOUT ( sort { -M \$\$a > -M \$\$b } glob( "\$\$ARGV[0]" ) )[0]' '\$(TEST_FILES)') test
 MAKE_FRAGMENT
 
     my $prove = _which 'prove';
@@ -60,23 +51,15 @@ MAKE_FRAGMENT
 # runs test scripts through TAP::Harness (prove) instead of Test::Harness (ExtUtils::MakeMaker)
 .PHONY: testp
 testp: pure_all
-	\$(NOECHO) \$(FULLPERLRUN) $prove\$(if \$(TEST_VERBOSE:0=), --verbose) --norc@{ [ -f $prove_rc_file ? " --rc $prove_rc_file"  : () ] } --recurse --shuffle \$(TEST_FILES)
+	\$(NOECHO) $prove\$(if \$(TEST_VERBOSE:0=), --verbose) --norc${ \( -f $prove_rc_file ? " --rc $prove_rc_file"  : '' ) } --blib --recurse --shuffle \$(TEST_FILES)
 MAKE_FRAGMENT
 
-    $make_fragment .= <<"MAKE_FRAGMENT" if _which 'cover';
+    my $cover = _which 'cover';
+    $make_fragment .= <<"MAKE_FRAGMENT" if $cover;
 
 .PHONY: cover
 cover:
-	\$(NOECHO) cover -test -ignore @{ [ basename( $local_lib_root ) ] } -report vim
-MAKE_FRAGMENT
-
-    $make_fragment .= <<"MAKE_FRAGMENT" if _which 'cpantorpm';
-
-# this definition of the CPAN to RPM target does not require that the
-# environment variables PERL_MM_OPT, and PERL_MB_OPT are undefined
-.PHONY: torpm
-torpm: tardist
-	\$(NOECHO) cpantorpm --debug --NO-DEPS --install-base $Config{ prefix } --install-type site \$(DISTVNAME).tar\$(SUFFIX)
+	\$(NOECHO) $cover -test -ignore ${ \( basename( $local_lib_root ) ) } -report vim
 MAKE_FRAGMENT
 
     return $make_fragment;
